@@ -1,6 +1,6 @@
 /*
-  calendarmodule.c: Copyright (C) 1997-2002 Tadayoshi Funaba All rights reserved
-  $Id: calendarmodule.c,v 1.12 2002-06-08 01:13:55+09 tadf Exp $
+  calendarmodule.c: Copyright (C) 1997-2002,2007 Tadayoshi Funaba All rights reserved
+  $Id: calendarmodule.c,v 1.13 2007-12-24 21:46:35+09 tadf Exp $
 */
 
 #include "ruby.h"
@@ -514,7 +514,11 @@ static double
 getfloat(VALUE x)
 {
     if (TYPE(x) == T_FLOAT)
+#ifndef RFLOAT_VALUE
 	return RFLOAT(x)->value;
+#else
+	return RFLOAT_VALUE(x);
+#endif
     return (double)NUM2INT(x);
 }
 
@@ -1215,7 +1219,7 @@ Init_calendar(void)
 	 calendar_kyureki_day_of_week_from_absolute, 1);
     rb_define_const
 	(mod, "VERSION",
-	 rb_str_new2("$Revision: 1.12 $"));
+	 rb_str_new2("$Revision: 1.13 $"));
     rb_define_const
 	(mod, "DAY_NAMES",
 	 rb_ary_new3
