@@ -1,6 +1,6 @@
 /*
-  getdatemodule.c: Copyright (C) 1999, 2001 Tadayoshi Funaba All rights reserved
-  $Id: getdatemodule.c,v 1.4 2001-05-13 01:00:01+09 tadf Exp $
+  getdatemodule.c: Copyright (C) 1999,2001,2007 Tadayoshi Funaba All rights reserved
+  $Id: getdatemodule.c,v 1.5 2007-12-24 21:47:45+09 tadf Exp $
 */
 
 #include "ruby.h"
@@ -12,7 +12,7 @@ static VALUE
 getdate_getdate(int argc, VALUE *argv, VALUE obj)
 {
     VALUE str, time;
-    int len;
+    long len;
     char *cstr;
     time_t ctime, when;
 
@@ -48,5 +48,5 @@ Init_getdate(void)
     rb_define_module_function(mod, "getdate", getdate_getdate, -1);
     rb_define_const
 	(mod, "VERSION",
-	 rb_str_new2("$Revision: 1.4 $"));
+	 rb_str_new2("$Revision: 1.5 $"));
 }
